@@ -1,5 +1,5 @@
 package Mojolicious::Plugin::Yancy;
-our $VERSION = '0.005';
+our $VERSION = '0.006';
 # ABSTRACT: Embed a simple admin CMS into your Mojolicious application
 
 #pod =head1 SYNOPSIS
@@ -64,6 +64,18 @@ our $VERSION = '0.005';
 #pod
 #pod Get the currently-configured Yancy backend object.
 #pod
+#pod =head2 yancy.route
+#pod
+#pod Get the root route where the Yancy CMS will appear. Useful for adding
+#pod checks:
+#pod
+#pod     my $route = $c->yancy->route;
+#pod     my $auth_route = $route->parent->under( sub {
+#pod         # ... Check auth
+#pod         return 1;
+#pod     } );
+#pod     $auth_route->add_child( $route );
+#pod
 #pod =head2 yancy.list
 #pod
 #pod     my @items = $c->yancy->list( $collection, \%param, \%opt );
@@ -181,6 +193,40 @@ our $VERSION = '0.005';
 #pod Run the configured filters on the given C<$item_data>. C<$collection> is
 #pod a collection name. Returns the hash of C<$filtered_data>.
 #pod
+#pod =head1 TEMPLATES
+#pod
+#pod This plugin uses the following templates. To override these templates
+#pod with your own theme, provide a template with the same name. Remember to
+#pod add your template paths to the beginning of the list of paths to be sure
+#pod your templates are found first:
+#pod
+#pod     # Mojolicious::Lite
+#pod     unshift @{ app->renderer->paths }, 'template/directory';
+#pod     unshift @{ app->renderer->classes }, __PACKAGE__;
+#pod
+#pod     # Mojolicious
+#pod     sub startup {
+#pod         my ( $app ) = @_;
+#pod         unshift @{ $app->renderer->paths }, 'template/directory';
+#pod         unshift @{ $app->renderer->classes }, __PACKAGE__;
+#pod     }
+#pod
+#pod =over
+#pod
+#pod =item layouts/yancy.html.ep
+#pod
+#pod This layout template surrounds all other Yancy templates.  Like all
+#pod Mojolicious layout templates, a replacement should use the C<content>
+#pod helper to display the page content. Additionally, a replacement should
+#pod use C<< content_for 'head' >> to add content to the C<head> element.
+#pod
+#pod =item yancy/index.html.ep
+#pod
+#pod This is the main Yancy web application. You should not override this. If
+#pod you need to, consider filing a bug report or feature request.
+#pod
+#pod =back
+#pod
 #pod =head1 SEE ALSO
 #pod
 #pod =cut
@@ -210,6 +256,7 @@ sub register( $self, $app, $config ) {
     push @{$app->routes->namespaces}, 'Yancy::Controller';
 
     # Helpers
+    $app->helper( 'yancy.route' => sub { return $route } );
     $app->helper( 'yancy.backend' => sub {
         state $backend;
         if ( !$backend ) {
@@ -259,7 +306,6 @@ sub register( $self, $app, $config ) {
         spec => $self->_build_openapi_spec( $config ),
     } );
 
-    $route->get( '/api' )->name( 'yancy.api' );
 }
 
 sub _build_openapi_spec( $self, $config ) {
@@ -500,7 +546,7 @@ Mojolicious::Plugin::Yancy - Embed a simple admin CMS into your Mojolicious appl
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
@@ -570,6 +616,18 @@ This plugin adds some helpers for use in routes, templates, and plugins.
 
 Get the currently-configured Yancy backend object.
 
+=head2 yancy.route
+
+Get the root route where the Yancy CMS will appear. Useful for adding
+checks:
+
+    my $route = $c->yancy->route;
+    my $auth_route = $route->parent->under( sub {
+        # ... Check auth
+        return 1;
+    } );
+    $auth_route->add_child( $route );
+
 =head2 yancy.list
 
     my @items = $c->yancy->list( $collection, \%param, \%opt );
@@ -687,6 +745,40 @@ fields.
 Run the configured filters on the given C<$item_data>. C<$collection> is
 a collection name. Returns the hash of C<$filtered_data>.
 
+=head1 TEMPLATES
+
+This plugin uses the following templates. To override these templates
+with your own theme, provide a template with the same name. Remember to
+add your template paths to the beginning of the list of paths to be sure
+your templates are found first:
+
+    # Mojolicious::Lite
+    unshift @{ app->renderer->paths }, 'template/directory';
+    unshift @{ app->renderer->classes }, __PACKAGE__;
+
+    # Mojolicious
+    sub startup {
+        my ( $app ) = @_;
+        unshift @{ $app->renderer->paths }, 'template/directory';
+        unshift @{ $app->renderer->classes }, __PACKAGE__;
+    }
+
+=over
+
+=item layouts/yancy.html.ep
+
+This layout template surrounds all other Yancy templates.  Like all
+Mojolicious layout templates, a replacement should use the C<content>
+helper to display the page content. Additionally, a replacement should
+use C<< content_for 'head' >> to add content to the C<head> element.
+
+=item yancy/index.html.ep
+
+This is the main Yancy web application. You should not override this. If
+you need to, consider filing a bug report or feature request.
+
+=back
+
 =head1 SEE ALSO
 
 =head1 AUTHOR
