@@ -1,5 +1,5 @@
 package Yancy;
-our $VERSION = '0.005';
+our $VERSION = '0.006';
 # ABSTRACT: A simple CMS for administrating data
 
 #pod =head1 SYNOPSIS
@@ -42,7 +42,8 @@ our $VERSION = '0.005';
 #pod Yancy can manage data in multiple databases using different backends
 #pod (L<Yancy::Backend> modules). Backends exist for L<Postgres via
 #pod Mojo::Pg|Yancy::Backend::Pg>, L<MySQL via
-#pod Mojo::mysql|Yancy::Backend::Mysql>, and L<DBIx::Class, a Perl
+#pod Mojo::mysql|Yancy::Backend::Mysql>, L<SQLite via
+#pod Mojo::SQLite|Yancy::Backend::SQLite>, and L<DBIx::Class, a Perl
 #pod ORM|Yancy::Backend::DBIC>
 #pod
 #pod =head2 Standalone App
@@ -182,6 +183,10 @@ our $VERSION = '0.005';
 #pod
 #pod     backend => 'mysql://user@localhost/mydb',
 #pod
+#pod =item L<SQLite backend|Yancy::Backend::SQLite>
+#pod
+#pod     backend => 'sqlite:filename.db',
+#pod
 #pod =item L<DBIx::Class backend|Yancy::Backend::Dbic>
 #pod
 #pod     backend => 'dbic://My::Schema/dbi:SQLite:file.db',
@@ -417,7 +422,7 @@ Yancy - A simple CMS for administrating data
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
@@ -455,7 +460,8 @@ the L<Mojolicious> web framework.
 Yancy can manage data in multiple databases using different backends
 (L<Yancy::Backend> modules). Backends exist for L<Postgres via
 Mojo::Pg|Yancy::Backend::Pg>, L<MySQL via
-Mojo::mysql|Yancy::Backend::Mysql>, and L<DBIx::Class, a Perl
+Mojo::mysql|Yancy::Backend::Mysql>, L<SQLite via
+Mojo::SQLite|Yancy::Backend::SQLite>, and L<DBIx::Class, a Perl
 ORM|Yancy::Backend::DBIC>
 
 =head2 Standalone App
@@ -595,6 +601,10 @@ below. See your backend's documentation for more information.
 
     backend => 'mysql://user@localhost/mydb',
 
+=item L<SQLite backend|Yancy::Backend::SQLite>
+
+    backend => 'sqlite:filename.db',
+
 =item L<DBIx::Class backend|Yancy::Backend::Dbic>
 
     backend => 'dbic://My::Schema/dbi:SQLite:file.db',
@@ -795,6 +805,22 @@ L<JSON schema|http://json-schema.org>, L<Mojolicious>
 
 Doug Bell <preaction@cpan.org>
 
+=head1 CONTRIBUTORS
+
+=for stopwords Mohammad S Anwar William Lindley
+
+=over 4
+
+=item *
+
+Mohammad S Anwar <mohammad.anwar@yahoo.com>
+
+=item *
+
+William Lindley <wlindley@wlindley.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2017 by Doug Bell.
@@ -807,51 +833,23 @@ the same terms as the Perl 5 programming language system itself.
 __DATA__
 
 @@ not_found.development.html.ep
-<!DOCTYPE html>
-<html>
-    <head>
-        <title>Yancy CMS</title>
-        <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/4.0.0-beta/css/bootstrap.min.css" type="text/css">
-        <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/css/font-awesome.min.css"
-            rel="stylesheet">
-        <script src="https://cdnjs.cloudflare.com/ajax/libs/jquery/3.2.1/jquery.min.js"></script>
-        <script src="https://cdnjs.cloudflare.com/ajax/libs/popper.js/1.12.8/umd/popper.min.js"></script>
-        <script src="https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/4.0.0-beta/js/bootstrap.min.js"></script>
-    </head>
-    <body>
+% layout 'yancy';
+<main id="app" class="container-fluid" style="margin-top: 10px">
+    <div class="row">
+        <div class="col-md-12">
+            <h1>Welcome to Yancy</h1>
+            <p>This is the default not found page.</p>
 
-        <nav class="navbar navbar-expand-lg navbar-light bg-light">
-          <a class="navbar-brand" href="<%= url_for('admin') %>">Yancy</a>
-          <button class="navbar-toggler" type="button" data-toggle="collapse" data-target="#navbarSupportedContent" aria-controls="navbarSupportedContent" aria-expanded="false" aria-label="Toggle navigation">
-            <span class="navbar-toggler-icon"></span>
-          </button>
-          <div class="collapse navbar-collapse" id="navbarSupportedContent">
-            <ul class="navbar-nav mr-auto">
-              <li class="nav-item active">
-                <a class="nav-link" href="<%= url_for('admin') %>">Admin</a>
-              </li>
+            <h2>Getting Started</h2>
+            <p>To edit your data, go to <a href="/admin">/admin</a>.</p>
+            <p>Add your templates to <tt><%= app->home->child( 'templates' ) %></tt>. Each template becomes a URL in your
+            site:</p>
+            <ul>
+                <li><tt><%= app->home->child( 'templates', 'foo.html.ep' ) %></tt> becomes <a href="/foo">/foo</a>.</li>
+                <li><tt><%= app->home->child( 'templates', 'foo', 'bar.html.ep' ) %></tt> becomes <a href="/foo/bar">/foo/bar</a>.</li>
             </ul>
-          </div>
-        </nav>
-
-        <main id="app" class="container-fluid" style="margin-top: 10px">
-            <div class="row">
-                <div class="col-md-12">
-                    <h1>Welcome to Yancy</h1>
-                    <p>This is the default not found page.</p>
-
-                    <h2>Getting Started</h2>
-                    <p>To edit your data, go to <a href="/admin">/admin</a>.</p>
-                    <p>Add your templates to <tt><%= app->home->child( 'templates' ) %></tt>. Each template becomes a URL in your
-                    site:</p>
-                    <ul>
-                        <li><tt><%= app->home->child( 'templates', 'foo.html.ep' ) %></tt> becomes <a href="/foo">/foo</a>.</li>
-                        <li><tt><%= app->home->child( 'templates', 'foo', 'bar.html.ep' ) %></tt> becomes <a href="/foo/bar">/foo/bar</a>.</li>
-                    </ul>
-                    <p>To disable this page, run Yancy in production mode with <kbd>-m production</kbd>.</p>
-                </div>
-            </div>
-        </main>
-    </body>
-</html>
+            <p>To disable this page, run Yancy in production mode with <kbd>-m production</kbd>.</p>
+        </div>
+    </div>
+</main>
 
